@@ -12,7 +12,7 @@ use aliased 'Exporter::Declare::Export::Generator';
 
 BEGIN { Meta->new(__PACKAGE__) }
 
-our $VERSION  = '0.112';
+our $VERSION  = '0.114';
 our @CARP_NOT = qw/
     Exporter::Declare
     Exporter::Declare::Specs
@@ -227,6 +227,7 @@ sub _is_exporter_class {
     # otherwise we fall back to $name->can().
     {
         no strict 'refs';
+        no warnings 'once';
         return 0 unless keys %{"$name\::"};
         return 1 if defined *{"$name\::export_meta"}{CODE};
         return 0 unless @{"$name\::ISA"};
@@ -331,7 +332,7 @@ system allows for top-notch introspection.
     # You can create a function to mangle the arguments before they are
     # parsed into a Exporter::Declare::Spec object.
     sub alter_import_args {
-       my ($class, $args) = @_;
+       my ($class, $importer, $args) = @_;
 
        # fiddle with args before importing routines are called
        @$args = grep { !/^skip_/ } @$args
@@ -393,7 +394,7 @@ names, unless prefixed with C<-> or C<:> In which case they may be a tag or an
 option. Exports without a sigil are assumed to be code exports, variable
 exports must be listed with their sigil.
 
-Items prefixed with the C<!> symbol are forcfully excluded, regardless of any
+Items prefixed with the C<!> symbol are forcefully excluded, regardless of any
 listed item that may normally include them. Tags can also be excluded, this
 will effectively exclude everything in the tag.
 
@@ -440,9 +441,9 @@ no argument is provided to import.
 
 =item -alias
 
-Every package has an alias that it can export. This is the last segmant of the
+Every package has an alias that it can export. This is the last segment of the
 packages namespace. IE C<My::Long::Package::Name::Foo> could export the C<Foo()>
-function. These alias functionis simply return the full package name as a
+function. These alias functions simply return the full package name as a
 string, in this case C<'My::Long::Package::Name::Foo'>. This is similar to
 L<aliased>.
 
@@ -522,7 +523,7 @@ You can use all three at once, but this is really a bad idea, documented for com
 The example above will work fine, all the arguments will make it into the
 generator. The only valid reason for this to work is that you may provide
 arguments such as C<-prefix> to a tag that brings in generator(), while also
-desiring to give arguments to generator() independantly.
+desiring to give arguments to generator() independently.
 
 =head1 PRIMARY EXPORT API
 
@@ -637,7 +638,7 @@ their own (See L<Exporter::Declare::Export>).
 =head1 META CLASS
 
 All exporters have a meta class, the only way to get the meta object is to call
-the exporter_meta() method on the class/object that is an exporter. Any class
+the export_meta() method on the class/object that is an exporter. Any class
 that uses Exporter::Declare gets this method, and a meta-object.
 
 =head1 AUTHORS
